@@ -1,4 +1,4 @@
-__version__ = "0.11"
+__version__ = "0.13"
 import logging
 import os
 import time
@@ -93,11 +93,13 @@ class Connect:
             "Content-Type": "application/json",
         }
         if method == "GET":
-            r = requests.get(href, headers=headers,)
+            r = requests.get(href, headers=headers)
+        elif method == "PUT":
+            r = requests.put(href, json=data, headers=headers)
         elif method == "POST":
-            r = requests.post(href, json=data, headers=headers,)
+            r = requests.post(href, json=data, headers=headers)
         elif method == "DELETE":
-            r = requests.delete(href, headers=headers,)
+            r = requests.delete(href, headers=headers)
             return True
         return if_success(r, msg, successcode)
 
