@@ -14,30 +14,26 @@ class LibLynxAuthMiddleware:
         self.product_cache = {}
 
     def authenticate(self, request):
-        # If the request has a _ll_ignore_host parameter, ignore the host, thus forcing a WAYF identification
-        # This enables us to allow anonynous access for users who do no wish to authenticate,
-        # but still allow a "Login" button
-        if "_ll_ignore_host" in request.GET:
-            host = "127.0.0.127"  # we do need to supply a valid IP address to the API
-        else:
-            host = request.META.get("HTTP_X_FORWARDED_FOR", "127.0.0.127")
-
+        host = request.META.get("HTTP_X_FORWARDED_FOR", "127.0.0.127")
         abs_uri = request.build_absolute_uri()
         user_agent = request.headers.get("User-Agent", "<unknown>")
 
         logging.debug(
             f"Trying New identification for \nhost: [{host}]\nurl: [{abs_uri}]\nuser agent: [{user_agent}]",
         )
-        identification = self.ll.new_identification(host, abs_uri, user_agent,)
+        identification = self.ll.new_identification(host, abs_uri, user_agent)
         logging.debug(identification)
-        if identification["status"] == "wayf":  # Needs a redirect to authenticate
+
+        if (
+            "_ll_allow_wayf" in request.GET and identification["status"] == "wayf"
+        ):  # Needs a redirect to authenticate
             return HttpResponseRedirect(identification["_links"]["wayf"]["href"])
 
         if identification["status"] == "identified":
             request.session["LIBLYNX_ACCOUNT"] = identification["account"][
                 "account_name"
             ]
-            request.session["LIBLYNX_ACCOUNT_ID"] = identification["account"]["id"]
+            request.session["LIBLYNX_ACCOUNT_ID"] = identification["account"].get("publisher_reference", "?")
 
             # Get the account information, so that we can retrieve the subscriptions
             account = self.ll.api(
@@ -59,14 +55,13 @@ class LibLynxAuthMiddleware:
 
                 request.session["LIBLYNX_PRODUCTS"] = products
                 logging.debug(f"Products found {products}")
+        elif identification["status"] == "wayf":
+            # Not idenitified if we get to there, so make it anonymous
+            request.session["LIBLYNX_ACCOUNT"] = ""
+            request.session["LIBLYNX_ACCOUNT_ID"] = "anon"
 
     def __call__(self, request):
-        if "_ll_ignore_host" in request.GET and "LIBLYNX_ACCOUNT" in request.session:
-            logging.debug(
-                "_ll_ignore_host called, deleting the LIBLYNX_ACCOUNT from session"
-            )
-            del request.session["LIBLYNX_ACCOUNT"]
-        if "LIBLYNX_ACCOUNT" not in request.session:
+        if "LIBLYNX_ACCOUNT" not in request.session or "_ll_allow_wayf" in request.GET:
             response = self.authenticate(request)
             if response is not None:
                 return response
